Class: Flipside::Entity
- Inherits:
-
ActiveRecord::Base
- Object
- ActiveRecord::Base
- Flipside::Entity
- Defined in:
- app/models/flipside/entity.rb
Overview
A join table to map entities to a Feature
A join table to map entities to a Feature