Class: Flipside::Key
- Defined in:
- app/models/flipside/key.rb
Overview
This class piggybacks on the Role class. They both need the same data, so it feels a bit unnecessary to have two similar db tables.
Constant Summary collapse
- KEY_CLASS =
"_FlipsideKey_"